#pragma rtGlobals=1		// Use modern global access method.
#include  <All IP Procedures>

// version 2011_05_04
//
//  window name: twoletters+datafoldername, in this way the datafolder is always identified unambiguously
// 	"PR" for single image
//	"WF" for waterfall
//	"WP(Q)" for waterfall profile
//	"RO" for ROI scan
//
// wave name: image stack as datafolder, single image as image
//
// Image profiles
// window name:	"PR"+datafolder
// xwave (p):		"PR"+datafolder+"_P"
// xwave (q):		"PR"+datafolder+"_Q"
// xwave (c):		"PR"+datafolder+"_C"
// ywave: 		anyname
//
// Waterfall
// window name:	"WF"+datafolder
// pwave (bottom):	"WF"+datafolder+"_P"
// qwave (left):	"WF"+datafolder+"_Q"
// qwave (right):	"WF"+datafolder+"_C"
// image: 		datafolder+"_WF"
//
// Waterfall profile Q (left or right axis)
// window name:	"WQ(C)"+datafolder
// xwave (q):		"WQ"+datafolder+"_P"
// ywave (p):		"WQ"+datafolder+"_Q(C)+pcsr(A)"
//
// Waterfall profile P (bottomt axis)
// window name:	"WP"+datafolder
// xwave (q):		"WP"+datafolder+"_P"
// ywave (p):		"WP"+datafolder+"_P+qcsr(A)"
//
// ROI scan
// window name:	"RO"+datafolder
// xwave (q):		"RO"+datafolder+"_P"
// ywave (p):		anyname (default: datafolder+"_ROI"

Menu "Profiles and ROI"
"Initialize"
"Show_ROI_tools"
"Do_ROI_scan"
"Do_LEED_IV"
"Do_LEED_IT"
"Correct_LEED_image"
"Extract_Free_Profile"
"Extract_WaterFall"
"Extract_Profile_from_WaterFall"
End

Proc Initialize()
	SetDataFolder root:SIS
	// cursors
	Variable/G lastcrsAp=0,lastcrsBp=500,lastcrsAq=0,lastcrsBq=500,lastprowidth=7
	// conversion factors for DP KE
	Variable/G  KE=0, xzero=160, pix2ev=26
	// conversion factors for DP BE
	Variable/G KEofFE=0, pixPosFE=160
	// last chosen
	Variable/G lastChoice=3, lastSpotRadius=10,lastBkgRadius=10, lastBkgWidth=5
	Variable/G lastchoice
end

Proc Show_ROI_tools()
	// recall data folder
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr):
	// recall ROI tools
	WMCreateImageROIPanel();
End

Proc Do_ROI_scan()
	PROI_extract_ROI()
end

Proc DO_LEED_IV()
	PROI_LEED_IV()
end

Proc DO_LEED_IT()
	PROI_LEED_IT()
end

Proc Extract_Free_Profile()
	PROI_extract_profile()
end

Proc Extract_WaterFall()
	PROI_extract_WF()
end

Proc Extract_Profile_from_WaterFall()
	PROI_extract_WF_profile()
end

Function PROI_extract_profile()
	//  globals
	NVAR lastcrsAp = root:SIS:lastcrsAp
	NVAR lastcrsBp = root:SIS:lastcrsBp
	NVAR lastcrsAq = root:SIS:lastcrsAq
	NVAR lastcrsBq = root:SIS:lastcrsBq
	NVAR lastprowidth = root:SIS:lastprowidth
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	print dfStr
	String stackStr=SIS_getImageStackName()	
	// input profile width
	variable prowidth=lastprowidth
	prompt prowidth, "profile width"
	doPrompt "input image stack" prowidth
	lastprowidth=prowidth
	// cursors
	if (stringMatch(num2Str(pcsr(A)),"NaN")!=1 && stringMatch(num2Str(pcsr(B)),"NaN")!=1)
		variable p1=pcsr(A)
		variable p2=pcsr(B)
		variable q1=qcsr(A)
		variable q2=qcsr(B)
		lastcrsAp=p1
		lastcrsBp=p2
		lastcrsAq=q1
		lastcrsBq=q2
	else
		p1= lastcrsAp
		p2 = lastcrsBp
		q1= lastcrsAq
		q2 = lastcrsBq
	endif
	// draw line
	SetDrawLayer UserFront
	setDrawEnv xcoord= top,ycoord= left,linefgc= (65280,0,0)		
	DrawLine p1,q1,p2,q2
	// calc profile
	variable npixels=round(sqrt((p2-p1)^2+(q2-q1)^2 ))+1
	variable theta=-atan2((q2-q1),(p2-p1))
	make/n=(npixels)/o ptmp,qtmp
	ptmp[]=p1+(p2-p1)/(npixels-1)*p 
	qtmp[]=q1+(q2-q1)/(npixels-1)*p  
	// show in graph
	variable nr=dimSize($stackStr,2)
	// get the layer
	NVAR layer=root:$(dfStr):layer
	if (nr==0)
		layer=-1
	endif
	if (layer <= nr)
		ImageLineProfile/P=(layer) srcWave=$stackStr, xWave=ptmp, yWave=qtmp, width=prowidth
		String proStr
		if (layer==-1)
			layer=0
		endif
		print layer
		if (layer < 10)
			proStr="PR"+stackStr+"_00"+num2str(layer)
		else
		 	if (layer < 100)
		 		proStr="PR"+stackStr+"_0"+num2str(layer)
		 	else
				proStr="PR"+stackStr+"_"+num2str(layer)	 	
		 	endif
		endif
		String proxStr="PR"+dfStr+"_P"
		duplicate/o W_ImageLineProfile $proStr, $proxStr
		wave wp=$proxStr
		wp=p 
		String graphNameStr="PR"+dfStr
		SIS_graphToFront(graphNameStr,proStr,proxStr)
		// control bar & buttons
		ControlBar 21
		button xToPixelButton, proc=PROI_xtoPixel ,pos={1,1} , size={79,18}, title="x to pixel" 
		button xToNanoButton, proc=PROI_xtoNano ,pos={81,1} , size={79,18}, title="x to nm" 
		button xtoKEButton, proc=PROI_xtoKE ,pos={161,1} , size={79,18}, title="x to KE" 
		button xtoBEButton, proc=PROI_xtoBE ,pos={241,1} , size={79,18}, title="x to BE" 
		button xtoKspaceButton, proc=PROI_xtoKspace ,pos={321,1} , size={79,18}, title="x to Kspace" 
		Label bottom "\\F'Arial'\\Z18Pixels"
		Label left "\\F'Arial'\\Z18Intensity (Arb. Units.)"
		SetAxis/A bottom
		ModifyGraph fSize=12
	endif
	killwaves qtmp,ptmp
End

Function PROI_xtoPixel(ctrlname): buttoncontrol
	// identifies datafolder and x wave
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winNameStr=SIS_getWinName()
	String xStr=winNameStr+"_P"
	wave wp=$xStr
	wp=p
	Label bottom "\\F'Arial'\\Z18Pixels"
	ModifyGraph log=0
	SetAxis/A bottom
End

Function PROI_xtoNano(ctrlname): buttoncontrol
	// identifies datafolder and x wave
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winNameStr=SIS_getWinName()
	String xStr=winNameStr+"_P"
	wave wp=$xStr
	// input
	variable fieldofView=2
	Prompt fieldofView,"field of view (um)"
	variable binning=2
	Prompt binning, "binning", popup "1x1;2x2;4x4;8x8"
	doPrompt "conversion" fieldofView, binning
	variable scaling=870
	wp=2^(binning-1)*1000*(-numpnts(wp)/2+p)*fieldofView/(scaling)
	Label bottom "\\F'Arial'\\Z18nm"
	ModifyGraph log=0
	SetAxis/A bottom
End

Function PROI_xtoKE(ctrlname): buttoncontrol
	// identifies datafolder and x wave
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winNameStr=SIS_getWinName()
	String xStr=winNameStr+"_P"
	wave wp=$xStr
	// ask for conversion parameters
	NVAR KE = root:SIS:KE
	NVAR xzero = root:SIS:xzero
	NVAR pix2eV = root:SIS:pix2eV
	variable this_KE=KE
	variable this_xzero=xzero
	variable this_pix2eV=pix2eV
	prompt this_KE, "start voltage of DP image (eV):"
	prompt this_xzero, "postion of e-beam (pixels)"
	prompt this_pix2eV, "conversion factor (pixels per eV):"
	doPrompt "converting pixels to eV", this_KE,this_xzero,this_pix2eV
	//convert
	if (V_flag == 0)
			Label bottom "\\F'Arial'\\Z18Kinetic energy (eV)"
			ModifyGraph log=0
			SetAxis/A bottom
			wp=PROI_toKE(p,this_KE,this_xzero,this_pix2eV)
			KE=this_KE
			xzero=this_xzero
			pix2eV=this_pix2ev
			SetAxis/A bottom
	endif
End

function PROI_toKE(pix,ke,zero,eV2pix)
	variable pix,ke,zero,eV2pix
	// pix = x axis (in pixels) of disp plane profile from csrA to crsB
	// zero = position in pixels of electron beam
	// ke = start voltage of e-beam
	// eV2pix = conversion factor 1ev to pixels
	return ke+(pix-zero)/eV2pix+PROI_dispersiveScaleCorrection(pix,zero) 
end

function PROI_dispersiveScaleCorrection(pix,zero)
	variable pix,zero
	// pix = x axis (in pixels) of disp plane profile from csrA to crsB
	// zero = position in pixels of electron beam
	variable diff=(pix-zero)+190
	return 0.51029+(-0.0078623*diff+4.1059e-05*diff^2-7.213e-08*diff^3)
end

Function PROI_xtoBE(ctrlname): buttoncontrol
	// identifies datafolder and x wave
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winNameStr=SIS_getWinName()
	String xStr=winNameStr+"_P"
	wave wp=$xStr
	// ask for conversion parameters
	NVAR KE = root:SIS:KE
	NVAR xzero = root:SIS:xzero
	NVAR pix2eV = root:SIS:pix2eV
	NVAR KEofFE = root:SIS:KEofFE
	NVAR pixPosFE = root:SIS:pixPosFE
	variable this_KE=KE
	variable this_xzero=xzero
	variable this_pix2eV=pix2eV
	variable this_KEofFE=KEofFE
	variable this_pixPosFE=pixPosFE
	prompt this_ke, "start voltage of DP image (eV):"
	prompt this_xzero, "postion of e-beam (pixels)"
	prompt this_pix2eV, "conversion factor (pixels per eV):"
	prompt this_KEofFE, "start voltage of Fermi edge image (eV):"
	prompt this_pixPosFE, "position of fermi edge (pixels);"
	doPrompt "converting pixels to eV", this_ke,this_xzero,this_pix2eV,this_KEofFE,this_pixPosFE
	//convert
	if (V_flag == 0)
			Label bottom "\\F'Arial'\\Z18Binding energy (eV)"
			SetAxis/A bottom
			ModifyGraph log=0
			wp=-PROI_toBE(p,this_KE,this_KEofFE,this_xzero,this_pixPosFE,this_pix2eV)
			ke=this_ke
			xzero=this_xzero
			pix2eV=this_pix2ev
			KEofFE=this_KEofFE
			pixPosFE=this_pixPosFE
	endif
End

function PROI_toBE(pix,ke,kefe,zero,posfe,eV2pix)
	variable pix,ke,kefe,zero,posfe,eV2pix
	// pix = x axis (in pixels) of disp plane profile from csra=(457,135) to crsB=(209,436)
	// zero = position in pixels of electron beam
	// ke = start voltage of e-beam
	// kefe = start voltage of e-beam for fermi edge disp plane image
	// pixel pos of fermi edge
	// eV2pix = conversion factor 1ev to pixels
	return  PROI_toKe(posfe,kefe,zero,eV2pix)-PROI_toKE(pix,ke,zero,eV2pix)
end

Function PROI_xtoKspace(ctrlname): buttoncontrol
	// identifies datafolder and x wave
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String xStr=winStr+"_P"
	wave wp=$xStr
	// cursors
	Showinfo
	SIS_PauseForCursors(winStr,"Adjust cursors")	
	//input
	variable binning=2
	Prompt binning, "binning", popup "(1x1);(2x2);(4x4);(8x8)"
	variable cali=0.0031 
	Prompt cali, "reciprocal space calibration (inverse angstrom per pixel / 2 Pi)"
	variable units=2
	Prompt units, "units", popup "pixels;inverse angstroms;"
	variable usecrsr=1
	Prompt usecrsr, "zero zero position", popup "cursor A;  csr (A+B)/2;"
	doPrompt "profile rescale input" binning,cali, units, usecrsr
	//
	variable zz=NaN
	if (usecrsr==1)
			zz=pcsr(A)
	endif
	if (usecrsr==2)
			zz=(pcsr(A)+pcsr(B))/2
	endif
	if (V_flag == 0)
		binning=binning/2
		cali=cali*2*Pi*binning
		// correction for LEED
		make/n=4/o wcorr={-0.36311,1.0001,2.5782e-005,-3.059e-006}
		//
		wp=(p-zz)
		wp=wcorr[0]+wcorr[1]*wp+wcorr[2]*wp^2+wcorr[3]*wp^3
		wp*=cali
		Label bottom "\\F'Arial'\\Z18k\\B\\F'Symbol'//\\M\\F'Arial'\\Z18(\\S-1\\M\\F'Arial'\\Z18)"
		//if ( stringmatch(waveStr[1,2],"PR")==1)
		//	ModifyGraph log(left)=1
		//endif
		SetAxis/A bottom
	endif
End

Function PROI_extract_WF()
	//  globals
	NVAR lastcrsAp = root:SIS:lastcrsAp
	NVAR lastcrsBp = root:SIS:lastcrsBp
	NVAR lastcrsAq = root:SIS:lastcrsAq
	NVAR lastcrsBq = root:SIS:lastcrsBq
	NVAR lastprowidth = root:SIS:lastprowidth
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String stackStr=SIS_getImageStackName()
	String winNameStr=SIS_getWinName()
	// profile width
	variable prowidth=lastprowidth
	prompt prowidth, "profile width"
	doPrompt "input stack watefall" prowidth
	lastprowidth=prowidth
	// cursors
	if (stringMatch(num2Str(pcsr(A)),"NaN")!=1 && stringMatch(num2Str(pcsr(B)),"NaN")!=1)
		variable p1=pcsr(A)
		variable p2=pcsr(B)
		variable q1=qcsr(A)
		variable q2=qcsr(B)
		lastcrsAp=p1
		lastcrsBp=p2
		lastcrsAq=q1
		lastcrsBq=q2
	else
		p1= lastcrsAp
		p2 = lastcrsBp
		q1= lastcrsAq
		q2 = lastcrsBq
	endif
	// draw line
	SetDrawLayer UserFront
	setDrawEnv xcoord= top,ycoord= left,linefgc= (65280,0,0)		
	DrawLine p1,q1,p2,q2
	// calc profile
	variable npixels=round(sqrt((p2-p1)^2+(q2-q1)^2 ))+1
	variable theta=-atan2((q2-q1),(p2-p1))
	make/n=(npixels)/o ptmp,qtmp
	ptmp[]=p1+(p2-p1)/(npixels-1)*p 
	qtmp[]=q1+(q2-q1)/(npixels-1)*p  
	// show in WF
	variable nr=dimSize($stackStr,2)
	if (nr>1)
		ImageLineProfile/P=-2 srcWave=$stackStr, xWave=ptmp, yWave=qtmp, width=prowidth
		String wfStr=stackStr+"_WF"
		String graphStr="WF"+stackStr
		// make p and q waves
		variable np=dimsize(M_ImageLineProfile,0)
		variable nq=dimsize(M_ImageLineProfile,1)
		String pStr="WF"+dfStr+"_P"
		String qStr="WF"+dfStr+"_Q"
		Make/N=(np+1)/o $pStr
		Make/N=(nq+1)/o $qStr
		wave wp=$pStr
		wave wq=$qStr
		wp=p 
		wq=p
		duplicate/o M_ImageLineProfile $wfstr
		SIS_xyImageToFront(graphStr,wfStr,pStr,qStr) 
		// control bar & buttons
		ControlBar 41
		button xToPixelButton, proc=PROI_xtoPixel ,pos={1,1} , size={79,18}, title="x to pixel" 
		button xToNanoButton, proc=PROI_xtoNano ,pos={81,1} , size={79,18}, title="x to nm" 
		button xtoKEButton, proc=PROI_xtoKE ,pos={161,1} , size={79,18}, title="x to KE" 
		button xtoBEButton, proc=PROI_xtoBE ,pos={241,1} , size={79,18}, title="x to BE" 
		button xtoKspaceButton, proc=PROI_xtoKspace ,pos={321,1} , size={79,18}, title="x to Kspace" 
		button setScaleLeftAxisButton, proc=PROI_setScaleLeftAxis ,pos={1,21} , size={79,18}, title="left axis"
		button setScaleRightAxisButton, proc=PROI_setScaleRightAxis ,pos={81,21} , size={79,18}, title="right axis"
		button rescaleButton, proc=PROI_rescale_axis ,pos={161,21} , size={79,18}, title="rescale axes" 
		button norm_image_bkgButton, proc=PROI_norm_image_bkg ,pos={241,21} , size={79,18}, title="norm@CRSs" 
		button killButton, proc=PROI_killwaves ,pos={321,21} , size={79,18}, title="kill" 	
		Label bottom "\\F'Arial'\\Z18Pixels"
		Label left "\\F'Arial'\\Z18Pixels"
		SetAxis/A bottom
		ModifyGraph fSize=12
		ModifyImage $wfStr ctab= {*,*,Terrain,0}
	endif
	killwaves qtmp,ptmp
End

Function PROI_setScaleLeftAxis(ctrlname): buttoncontrol
	// identifies datafolder and x wave
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winNameStr=SIS_getWinName()
	String qStr=winNameStr+"_Q"
	wave wq=$qStr
	variable axis=3
	Prompt axis, "left axis", popup "image number; IV (momentum transfer); kinetic energy; photon energy; time; temperature (TC); temperature (PY); focus; other;"
	doPrompt "left axis input" axis
	String yStr
	if (V_flag == 0) 
		if (axis==1)
		Prompt yStr, "enter wave",popup WaveList("*NUM*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==2)
			Prompt yStr, "enter wave",popup WaveList("*S*V*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==3)
			Prompt yStr, "enter wave",popup WaveList("*S*V*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==4)
			Prompt yStr, "enter wave",popup WaveList("*ner*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==5)
		Prompt yStr, "enter wave",popup WaveList("ti*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==6)
			Prompt yStr, "enter wave",popup WaveList("te*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==7)
			Prompt yStr, "enter wave",popup WaveList("p*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==8)
			Prompt yStr, "enter wave",popup WaveList("*OB*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (axis==9)
			Prompt yStr, "enter wave",popup WaveList("*",";","")
			doPrompt "left axis input wave" yStr
		endif
		if (V_flag==0)
			//assignment
			wave wy=$yStr
			wq=wy
			variable nq=numpnts(wq)
			wq[nq-1]+=(wq[nq-2]-wq[nq-3])
			// change label
			if (axis == 1)
				Label left "\\F'Arial'\\Z18Image number"
			endif
			if (axis == 2)
				Label left "\\F'Arial'\\Z18k\\B\\F'Symbol'^\\M\\F'Arial'\\Z18(\\S-1\\M\\F'Arial'\\Z18)"
				wq=2*0.512317*sqrt(wq)
			endif
			if (axis == 3)
				Label left "\\F'Arial'\\Z18Kinetic energy (eV)"
			endif
			if (axis == 4)
				Label left "\\F'Arial'\\Z18Photon energy (eV)"
			endif
			if (axis == 5)
				Label left "\\F'Arial'\\Z18Time (s)"
				wq/=1000
			endif
			if ((axis == 6) || (axis == 7))
				Label left "\\F'Arial'\\Z18Temperature (C)"
			endif
			if (axis == 8)
				Label left "\\F'Arial'\\Z18Current (mA)"
			endif
			if (axis == 9)
				Label left "\\F'Arial'\\Z18Other (Arb. Units)"
			endif
		endif
	endif	
end

Function PROI_setScaleRightAxis(ctrlname): buttoncontrol
	// identifies datafolder and x wave
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String pStr=winStr+"_P"
	String qStr=winStr+"_Q"
	String cStr=winStr+"_C"
	String imageStr=SIS_getImageStackName()
	wave wp=$pStr
	wave wq=$qStr	
	duplicate/o $qStr $cStr 
	wave wc=$cStr
	variable axis=1
	Prompt axis, "choose right axis", popup "image number; IV (momentum transfer); kinetic energy; photon energy; time; temperature (TC); temperature (PY); focus; other; coverage;"
	doPrompt "axis input" axis
	String yStr
	if (V_flag == 0) 
		if (axis==1)
			Prompt yStr, "enter wave",popup WaveList("*NUM*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==2)
			Prompt yStr, "enter wave",popup WaveList("*S*V*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==3)
			Prompt yStr, "enter wave",popup WaveList("*S*V*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==4)
			Prompt yStr, "enter wave",popup WaveList("*ner*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==5)
		Prompt yStr, "enter wave",popup WaveList("ti*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==6)
			Prompt yStr, "enter wave",popup WaveList("te*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==7)
			Prompt yStr, "enter wave",popup WaveList("p*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==8)
			Prompt yStr, "enter wave",popup WaveList("*OB*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==9)
			Prompt yStr, "enter wave",popup WaveList("*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (axis==10)
			Prompt yStr, "enter wave",popup WaveList("*",";","")
			doPrompt "right axis input wave" yStr
		endif
		if (V_flag==0)
			//assignment
			wave wy=$yStr
			wc=wy
			variable nq=numpnts(wc)
			wc[nq-1]+=(wc[nq-2]-wc[nq-3])
			string rightImageStr="'"+imageStr+"'#1"
			if (strlen(ImageInfo(winStr, imageStr, 1))==0) 
				// append image (if necessary)
				appendImage/R $imageStr vs {wp,wc} 
				ModifyImage $rightImageStr ctab= {*,*,Terrain,0} 
			endif
			ModifyGraph fSize=12
			if (axis == 1)
				Label right "\\F'Arial'\\Z18Image number"
			endif
			if (axis == 2)
				Label right "\\F'Arial'\\Z18k\\B\\F'Symbol'^\\M\\F'Arial'\\Z18(\\S-1\\M\\F'Arial'\\Z18)"
				wc=2*0.512317*sqrt(wc)
			endif
			if (axis == 3)
				Label right "\\F'Arial'\\Z18Kinetic energy (eV)"
			endif
			if (axis == 4)
				Label right "\\F'Arial'\\Z18Photon energy (eV)"
			endif
			if (axis == 5)
				Label right "\\F'Arial'\\Z18Time (s)"
				wc/=1000
			endif
			if ((axis == 6) || (axis == 7))
				Label right "\\F'Arial'\\Z18Temperature (C)"
			endif
			if (axis == 8)
				Label right "\\F'Arial'\\Z18Current (mA)"
			endif
			if (axis == 9)
				Label right "\\F'Arial'\\Z18Other (Arb. Units)"
			endif
			if (axis == 10)
				duplicate/o $qStr $cStr
				Label right "\\F'Arial'\\Z18Coverage (ps ML)"
				SIS_PauseForCursors(winStr,"Adjust crs A and B")	
				variable qa=min(qcsr(A),qcsr(B))
				variable qb=max(qcsr(A),qcsr(B))
				qb=min(qb,numpnts($cStr))
				variable m=abs(qb-qa)
				wc[]=(p-qa)/m
			endif
		endif
	endif	
end

Function PROI_norm_image_bkg(ctrlname): buttoncontrol
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String imageStr=SIS_getImageStackName()
	variable np=dimSize($imageStr,0)
	variable nq=dimSize($imageStr,1)
	// cursors
	SIS_PauseForCursors(winStr,"Adjust crs A and B")	
	variable p1=pcsr(A)
	variable p2=pcsr(B)
	variable i=0
	variable mvm=0
	variable mv
	wave w=$imageStr
	Redimension/S w
	do
		imageTransform/G=(i) getCol $imageStr
		mv=mean(W_ExtractedCol,p1,p2)
		duplicate/o W_ExtractedCol wtmp
		wtmp=wtmp/mv
		mvm+=mv
		imageTransform/G=(i)/D=wtmp putCol $imageStr
		i+=1
	while (i<nq)
	mvm/=nq
	w*=mvm
	killwaves wtmp
	ModifyImage $imageStr ctab= {0,*,Terrain,0}
end

Function PROI_rescale_axis(ctrlname): buttoncontrol
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String pStr=winStr+"_P"
	String qStr=winStr+"_Q"
	String cStr=winStr+"_C"
	String imageStr=SIS_getImageStackName()
	variable mode=1
	Prompt mode, "mode", popup "bottom; left; right"
	variable newvalue=1 //1.985//2.807
	Prompt newvalue,"new value at csr A"
	doPrompt "rescale input" mode, newvalue
	if (V_flag == 0)
		SIS_PauseForCursors(winStr,"Adjust cursor A")		
		variable scaling=1
		if (mode==1)
			wave wp=$pStr
			scaling=newvalue/wp[pcsr(A)]
			wp*=scaling
		endif
		if (mode==2)
			wave wq=$qStr
			scaling=newvalue/wq[qcsr(A)]
			wq*=scaling 
		endif
		if (mode==3)
			wave wc=$cStr
			scaling=newvalue/wc[qcsr(A)]
			wc*=scaling 
		endif
	endif
End

Function PROI_extract_WF_profile()
	NVAR lastprowidth = root:SIS:lastprowidth
	variable prowidth=lastprowidth
	prompt prowidth, "profile width"
	// set datafolder
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String imageStr=SIS_getImageStackName()
	String winStr=SIS_getWinName()
	SIS_PauseForCursors(winStr,"Adjust cursor A")
	// input
	variable axis=1
	Prompt axis, "axis", popup "left; bottom; right"
	doPrompt "input image stack" prowidth, axis	
	String graphStr
	// ok is pressed
	if (V_flag == 0)
		variable np=dimSize($imageStr,0)
		variable nq=dimSize($imageStr,1)	
		variable p1,p2,q1,q2
		variable x1,x2,y1,y2
		lastprowidth=prowidth
		String yStr="WF"+dfStr+"_Q"
		wave wy=$yStr
		String xStr="WF"+dfStr+"_P"
		wave wx=$xStr
		if (stringMatch(num2Str(pcsr(A)),"NaN")!=1)
			if (axis == 1 || axis == 3)
				p1=pcsr(A)
				p2=pcsr(A)
				q1=0
				q2=nq-1
				// needed to plot line
				x1=wx[pcsr(A)]
				x2=wx[pcsr(A)]
				y1=wy[0]
				y2=wy[nq-1]
			else 
				p1=0
				p2=np-1
				q1=qcsr(A)
				q2=qcsr(A)
				// needed to plot line
				x1=wx[0]
				x2=wx[np-1]
				y1=wy[qcsr(A)]
				y2=wy[qcsr(A)]
			endif
			// draw line
			SetDrawLayer UserFront
			setDrawEnv xcoord=bottom,ycoord=left,linefgc= (65280,0,0)		
			DrawLine x1,y1,x2,y2
			variable npixels=round(sqrt((p2-p1)^2+(q2-q1)^2 ))+1
			make/n=(npixels)/o ptmp,qtmp
			ptmp[]=p1+(p2-p1)/(npixels-1)*p 	
			qtmp[]=q1+(q2-q1)/(npixels-1)*p  
			// get line profile
			ImageLineProfile/P=-1 srcWave=$imageStr, xWave=ptmp, yWave=qtmp, width=prowidth
			String fprStr,fprxStr
			PauseUPdate
			if ((axis==1)||(axis==3))
				if (axis==1)
					graphStr="WQ"+dfStr
					fprStr="WQ"+dfStr+"_Q"+num2str(p1)
					fprxStr="WQ"+dfStr+"_P"
				endif
				if (axis==3)
					graphStr="WC"+dfStr
					fprStr="WC"+dfStr+"_C"+num2str(p1)
					fprxStr="WC"+dfStr+"_P"
				endif
				duplicate/o $yStr $fprxStr
				duplicate/o W_ImageLineProfile $fprstr
				redimension/n=(numpnts(W_ImageLineProfile)) $fprxStr
				SIS_graphToFront(graphStr,fprStr,fprxStr) 
				PROI_labelBottomAxis("bottom",1)
				// control bar & buttons
				ControlBar 21
				button xToCoverageButton, proc=PROI_bottomToCoverage ,pos={1,1} , size={79,18}, title="x to coverage" 
				button operationButton, proc=PROI_operations ,pos={81,1} , size={79,18}, title="operations" 
				button killButton, proc=PROI_killwaves ,pos={161,1} , size={79,18}, title="kill waves" 
			endif
			if (axis == 2)
				fprStr="WP"+dfStr+"_P"+num2str(q1)
				fprxStr="WP"+dfStr+"_P"
				graphStr="WP"+dfStr		
				duplicate/o W_ImageLineProfile $fprstr
				duplicate/o $xStr $fprxStr
				SIS_graphToFront(graphStr,fprStr,fprxStr) 
				PROI_labelBottomAxis("bottom",1)  	
				// control bar & buttons
				ControlBar 21
				button xToPixelButton, proc=PROI_xtoPixel ,pos={1,1} , size={79,18}, title="x to pixel" 
				button xToNanoButton, proc=PROI_xtoNano ,pos={81,1} , size={79,18}, title="x to nm" 
				button xtoKEButton, proc=PROI_xtoKE ,pos={161,1} , size={79,18}, title="x to KE" 
				button xtoBEButton, proc=PROI_xtoBE ,pos={241,1} , size={79,18}, title="x to BE" 
				button xtoKspaceButton, proc=PROI_xtoKspace ,pos={321,1} , size={79,18}, title="x to Kspace" 
			endif
			print graphStr,fprStr,fprxStr
			Label left "\\F'Arial'\\Z18Intensity (Arb. Units.)"
			ModifyGraph fSize=12
			ModifyGraph width=283.465
			ModifyGraph width=226.772,height={Aspect,1}
			killwaves qtmp,ptmp
		endif
	endif
End

Function PROI_labelBottomAxis(axisname,type)
	String axisname
	variable type
	variable labeltype=type
	Prompt labeltype, "x axis", popup "pixels;image number; IV; kinetic energy; photon energy; time; temperature (TC); temperature (PY); focus; other;"
	doPrompt "axes label" labeltype
	if (V_flag==0)	
		if (labeltype == 1)
			Label $(axisname) "\\F'Arial'\\Z18Pixels"
		endif
		if (labeltype == 2)
			Label $(axisname) "\\F'Arial'\\Z18Image number"
		endif
		if (labeltype == 3)
			Label bottom "\\F'Arial'\\Z18k\\B\\F'Symbol'^\\M\\F'Arial'\\Z18(\\S-1\\M\\F'Arial'\\Z18)"
		endif
		if (labeltype == 4)
			Label bottom "\\F'Arial'\\Z18Kinetic energy (eV)"
			endif
		if (labeltype == 5)
			Label bottom "\\F'Arial'\\Z18Photon energy (eV)"
		endif
		if (labeltype == 6)
			Label bottom "\\F'Arial'\\Z18Time (s)"
		endif
		if ((labeltype == 7) || (labeltype == 8))
			Label bottom "\\F'Arial'\\Z18Temperature (C)"
		endif
		if (labeltype == 9)
			Label bottom "\\F'Arial'\\Z18Current (mA)"
		endif
		if (labeltype == 10)
			Label bottom "\\F'Arial'\\Z18Other (Arb. Units)"
		endif 
	endif
end

Function PROI_extract_ROI()
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winNameStr=SIS_getWinName()
	String pStr="RO"+dfStr+"_P"
	String stackStr=SIS_getImageStackName()
	// input
	NVAR lastChoice=root:SIS:lastChoice
	variable axis=lastChoice
	Prompt axis, "x axis", popup "image number; start voltage; kinetic energy; photon energy; time; temperature (TC); temperature (PY); focus; other;"
	// 1 image number
	// 2 STV
	// 3 kinetic energy
	// 4 photon energy
	// 5 time
	// 6 temperature (TC)
	// 7 temperature (PY)
	// 8 focus
	// 9 other	
	doPrompt "choose ROI x axis wave" axis
	// init variables
	String roixStr="RO"+stackStr+"_P"	
	variable p=dimsize($stackStr,0)
	variable q=dimsize($stackStr,1)
	variable r=dimsize($stackStr,2)
	if ((V_flag == 0) && (r>1))
		NVAR lastchoice=root:SIS:lastchoice
		lastchoice=axis
		String xStr, graphStr="RO"+dfStr
		if (axis==1)
			Prompt xStr, "enter wave",popup WaveList("*NUM*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==2)
			Prompt xStr, "enter wave",popup WaveList("*S*V*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==3)
			Prompt xStr, "enter wave",popup WaveList("*S*V*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==4)
			Prompt xStr, "enter wave",popup WaveList("*ner*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==5)
		Prompt xStr, "enter wave",popup WaveList("ti*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==6)
			Prompt xStr, "enter wave",popup WaveList("te*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==7)
			Prompt xStr, "enter wave",popup WaveList("p*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==8)
			Prompt xStr, "enter wave",popup WaveList("*OB*",";","")
			doPrompt "left axis input wave" xStr
		endif
		if (axis==9)
			Prompt xStr, "enter wave",popup WaveList("*",";","")
			doPrompt "left axis input wave" xStr
		endif
		
		if (V_flag == 0) // if cancel is not pressed
			// duplicate chosen x wave into roixwave
			duplicate/o $xStr $roixStr
			wave wx=$roixStr
			// input ROI wavename
			String nameStr="ROI"
			nameStr=PROI_giveRoiName(nameStr)
			String roiStr = stackStr+"_"+nameStr
			make/n=(r)/o $roiStr
			wave wroi=$roiStr
			variable i=0
			// calc roiwave
			do
				ImageStats/P=(i)/R=M_ROIMask $stackStr // calc avg in the ROI in the datafolder
				wroi[i]=V_avg
				i+=1
			while(i<r)
			// display roiwave vs roixwave
			SIS_graphToFront(graphStr,roiStr,roixStr)

			if (axis == 1)
				Label bottom "\\F'Arial'\\Z18Image number"
			endif
			if (axis == 2)
				Label bottom "\\F'Arial'\\Z18Start voltage (eV)"
			endif
			if (axis == 3)
				Label bottom "\\F'Arial'\\Z18Kinetic energy (eV)"
			endif
			if (axis == 4)
				Label bottom "\\F'Arial'\\Z18Photon energy (eV)"
			endif
			if (axis == 5)
				Label bottom "\\F'Arial'\\Z18Time (s)"
				wx/=1000
			endif
			if ((axis == 6) || (axis == 7))
				Label bottom "\\F'Arial'\\Z18Temperature (C)"
			endif
			if (axis == 8)
				Label bottom "\\F'Arial'\\Z18Current (mA)"
			endif
			if (axis == 9)
				Label bottom "\\F'Arial'\\Z18Other (Arb. Units)"
			endif
			Label left "\\F'Arial'\\Z18Intensity (Arb. Units)"
			ModifyGraph fSize=12
			ModifyGraph width=226.772,height={Aspect,1}
			// control bar & buttons
			ControlBar 21
			button xToCoverageButton, proc=PROI_bottomToCoverage ,pos={1,1} , size={79,18}, title="x to coverage" 
			button operationButton, proc=PROI_operations ,pos={81,1} , size={79,18}, title="operations" 
			button killButton, proc=PROI_killwaves ,pos={161,1} , size={79,18}, title="kill waves" 
		endif
	endif
End

Function PROI_LEED_IV()
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	// String pStr="RO"+dfStr+"_P"
	String stackStr=SIS_getImageStackName()
	NVAR lastChoice=root:SIS:lastChoice
	NVAR lastSpotRadius=root:SIS:lastSpotRadius
	NVAR lastBkgRadius=root:SIS:lastBkgRadius
	NVAR lastBkgWidth=root:SIS:lastBkgWidth
	// input
	variable axis=2
	Prompt axis, "x axis label", popup "start voltage; kinetic energy;"
	String xStr, graphStr="RO"+dfStr
	Prompt xStr, "enter wave",popup WaveList("*S*V*",";","")
	variable bkgmode=1
	Prompt bkgmode, "remove bkg", popup "yes; no;"
	variable roiradius=lastSpotRadius
	Prompt roiradius, "ROI radius"
	variable bkgradius=lastBkgRadius
	Prompt bkgradius, "background radius"
	variable bkgwidth=lastBkgWidth
	Prompt bkgwidth, "background width"	
	doPrompt "LEED IV input" axis,xstr,bkgmode,roiradius,bkgradius,bkgwidth
	// init variables
	variable np=dimsize($stackStr,0)
	variable nq=dimsize($stackStr,1)
	variable r=dimsize($stackStr,2)
	if ((V_flag == 0) && (r>1))
		// put the cursors
		Showinfo
		SIS_PauseForCursors(winStr,"put cursorA on spot")
		// check for cursors
		if (strlen(CsrWave(A))>0)
			lastChoice=axis+1
			lastSpotRadius=roiradius
			lastBkgRadius=bkgradius
			lastBkgWidth=bkgwidth
			// duplicate chosen x wave into roixwave
			String roixStr="RO"+stackStr+"_P"	
			duplicate/o $xStr $roixStr
			wave wx=$roixStr
			// input ROI wavename
			String nameStr="ROI"
			nameStr=PROI_giveRoiName(nameStr)
			String roiStr = stackStr+"_"+nameStr
			String bkgStr = stackstr+"_"+nameStr+"B"
			// cursors
			variable pa=pcsr(A)
			variable qa=qcsr(A)
			variable outerbkgradius=bkgradius+bkgwidth
			SetDrawEnv xcoord= top,ycoord= left,textrgb= (65280,0,0);DelayUpdate
			DrawText pa,qa,nameStr
			// draw spot circle
			SetDrawEnv xcoord= top,ycoord= left,linefgc= (65280,0,0),fillpat= 0
			DrawOval pa-roiradius,qa-roiradius,pa+roiradius,qa+roiradius
			// draw inner bkg circle
			SetDrawEnv xcoord= top,ycoord= left,linefgc= (0,65280,0),fillpat= 0
			DrawOval pa-bkgradius,qa-bkgradius,pa+bkgradius,qa+bkgradius
			// draw outer bkg circle
			SetDrawEnv xcoord= top,ycoord= left,linefgc= (0,65280,0),fillpat= 0
			DrawOval pa-outerbkgradius,qa-outerbkgradius,pa+outerbkgradius,qa+outerbkgradius
			// waves
			make/n=(r)/o $roiStr,$bkgStr
			wave wroi=$roiStr
			wave wbkg=$bkgStr
			make/n=(np,nq)/o/U/B thisROI,bkgROI
			thisROI[][] =  (sqrt((p-pA)^2+(q-qA)^2) > roiradius)
			bkgROI[][]= (sqrt((p-pA)^2+(q-qA)^2) < bkgradius) + (sqrt((p-pA)^2+(q-qA)^2) > (bkgwidth+bkgradius)) 
			// loop that calculates ROI
			variable i=0
			do				
				ImageStats/P=(i)/R=thisROI $stackStr // calc avg in the ROI in the datafolder
				wroi[i]=V_avg
				ImageStats/P=(i)/R=bkgROI $stackStr // calc avg in the ROI in the datafolder
				wbkg[i]=V_avg
				i+=1
			while(i<r)
			if (bkgmode==1)
				wroi-=wbkg
			else
				SIS_graphToFront(graphStr,bkgstr,roixStr)
			endif
			// display roiwave vs roixwave
			SIS_graphToFront(graphStr,roiStr,roixStr)
			if (axis == 1)
				Label bottom "\\F'Arial'\\Z18Start voltage (eV)"
			endif
			if (axis == 2)
				Label bottom "\\F'Arial'\\Z18Kinetic energy (eV)"
			endif
			Label left "\\F'Arial'\\Z18Intensity (Arb. Units)"
			ModifyGraph fSize=12
			ModifyGraph width=226.772,height={Aspect,1}
			// control bar & buttons
			ControlBar 21
			button xToCoverageButton, proc=PROI_save_LEED_IV_txtwaves, pos={1,1} , size={79,18}, title="save waves" 
			button operationButton, proc=PROI_operations ,pos={81,1} , size={79,18}, title="operations" 
			button killButton, proc=PROI_killwaves ,pos={161,1} , size={79,18}, title="kill waves" 
		endif		
	endif
End

Function PROI_LEED_IT()
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	// String pStr="RO"+dfStr+"_P"
	String stackStr=SIS_getImageStackName()
	NVAR lastChoice=root:SIS:lastChoice
	NVAR lastSpotRadius=root:SIS:lastSpotRadius
	NVAR lastBkgRadius=root:SIS:lastBkgRadius
	NVAR lastBkgWidth=root:SIS:lastBkgWidth
	// input
	variable axis=2
	Prompt axis, "x axis label", popup "time;"
	String xStr, graphStr="RO"+dfStr
	Prompt xStr, "enter wave",popup WaveList("*t*",";","")
	variable bkgmode=1
	Prompt bkgmode, "remove bkg", popup "yes; no;"
	variable roiradius=lastSpotRadius
	Prompt roiradius, "ROI radius"
	variable bkgradius=lastBkgRadius
	Prompt bkgradius, "background radius"
	variable bkgwidth=lastBkgWidth
	Prompt bkgwidth, "background width"	
	doPrompt "LEED IV input" axis,xstr,bkgmode,roiradius,bkgradius,bkgwidth
	// init variables
	variable np=dimsize($stackStr,0)
	variable nq=dimsize($stackStr,1)
	variable r=dimsize($stackStr,2)
	if ((V_flag == 0) && (r>1))
		// put the cursors
		Showinfo
		SIS_PauseForCursors(winStr,"put cursorA on spot")
		// check for cursors
		if (strlen(CsrWave(A))>0)
			lastChoice=axis+1
			lastSpotRadius=roiradius
			lastBkgRadius=bkgradius
			lastBkgWidth=bkgwidth
			// duplicate chosen x wave into roixwave
			String roixStr="RO"+stackStr+"_P"	
			duplicate/o $xStr $roixStr
			wave wx=$roixStr
			wx/=1000
			// input ROI wavename
			String nameStr="ROI"
			nameStr=PROI_giveRoiName(nameStr)
			String roiStr = stackStr+"_"+nameStr
			String bkgStr = stackstr+"_"+nameStr+"B"
			// cursors
			variable pa=pcsr(A)
			variable qa=qcsr(A)
			variable outerbkgradius=bkgradius+bkgwidth
			SetDrawEnv xcoord= top,ycoord= left,textrgb= (65280,0,0);DelayUpdate
			DrawText pa,qa,nameStr
			// draw spot circle
			SetDrawEnv xcoord= top,ycoord= left,linefgc= (65280,0,0),fillpat= 0
			DrawOval pa-roiradius,qa-roiradius,pa+roiradius,qa+roiradius
			// draw inner bkg circle
			SetDrawEnv xcoord= top,ycoord= left,linefgc= (0,65280,0),fillpat= 0
			DrawOval pa-bkgradius,qa-bkgradius,pa+bkgradius,qa+bkgradius
			// draw outer bkg circle
			SetDrawEnv xcoord= top,ycoord= left,linefgc= (0,65280,0),fillpat= 0
			DrawOval pa-outerbkgradius,qa-outerbkgradius,pa+outerbkgradius,qa+outerbkgradius
			// waves
			make/n=(r)/o $roiStr,$bkgStr
			wave wroi=$roiStr
			wave wbkg=$bkgStr
			make/n=(np,nq)/o/U/B thisROI,bkgROI
			thisROI[][] =  (sqrt((p-pA)^2+(q-qA)^2) > roiradius)
			bkgROI[][]= (sqrt((p-pA)^2+(q-qA)^2) < bkgradius) + (sqrt((p-pA)^2+(q-qA)^2) > (bkgwidth+bkgradius)) 
			// loop that calculates ROI
			variable i=0
			do				
				ImageStats/P=(i)/R=thisROI $stackStr // calc avg in the ROI in the datafolder
				wroi[i]=V_avg
				ImageStats/P=(i)/R=bkgROI $stackStr // calc avg in the ROI in the datafolder
				wbkg[i]=V_avg
				i+=1
			while(i<r)
			if (bkgmode==1)
				wroi-=wbkg
			else
				SIS_graphToFront(graphStr,bkgstr,roixStr)
			endif
			// display roiwave vs roixwave
			SIS_graphToFront(graphStr,roiStr,roixStr)
			if (axis == 1)
				Label bottom "\\F'Arial'\\Z18Time (s)"
			endif
			if (axis == 2)
				Label bottom "\\F'Arial'\\Z18Time (s)"
			endif
			Label left "\\F'Arial'\\Z18Intensity (Arb. Units)"
			ModifyGraph fSize=12
			ModifyGraph width=226.772,height={Aspect,1}
			// control bar & buttons
			ControlBar 21
			button xToCoverageButton, proc=PROI_save_LEED_IV_txtwaves, pos={1,1} , size={79,18}, title="save waves" 
			button operationButton, proc=PROI_operations ,pos={81,1} , size={79,18}, title="operations" 
			button killButton, proc=PROI_killwaves ,pos={161,1} , size={79,18}, title="kill waves" 
		endif		
	endif
End

Function PROI_save_LEED_IV_txtwaves(ctrlname): buttoncontrol
	String ctrlname
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String yWavelistStr = WaveList("*", ";","WIN:") 
	String xWavelistStr = WaveList("RO*_P", ";","WIN:") 
	String mWaveStr = ""
	String tmpStr = ""
	String fname = ""
	variable n=ItemsInList(yWavelistStr) 
	variable m=0
	do
		mWaveStr=StringFromList(m, yWavelistStr)
		tmpStr =  xWavelistStr+"'"+mWaveStr+"';"
		fname = SIS_removeQuotes(mWaveStr)+".txt"
		fname = ReplaceString("/", fname, ".")
		fname = ReplaceString(",", fname, "_")
		fname = ReplaceString("*", fname, "x")
		if (m==0)
			newpath/C/M="enter path"/O savepath
		endif
		Save/O/G/B/P=savepath tmpStr as fname
		m+=1
	while(m < n)
end

Function PROI_operations(ctrlname): buttoncontrol
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winNameStr=SIS_getWinName()
	String stackStr=SIS_getImageStackName()		
	// choose operation
	variable operation=1
	Prompt operation, "wave operation", popup "divide;multiply;subtract;add;background"
	String oStr
	Prompt oStr, "enter wave",popup WaveList("*",";","")
	doPrompt "operations input" operation,oStr
	if (V_flag==0)
		wave ow=$oStr
		String wavelistStr = WaveList("!*_P", ";","WIN:") 
		variable n=ItemsInList(wavelistStr) 
		variable m=0
		String wavenameStr = ""
		do
			wavenameStr=StringFromList(m, wavelistStr) 
			wave w = $wavenameStr
			if (operation == 1)
				w/=ow
			endif
			if (operation == 2)
				w*=ow
			endif
			if (operation == 3)
				w-=ow
			endif
			if (operation == 4)
				w+=ow
			endif
			if (operation == 5)
				wavestats w
				w-=V_min
			endif
			m+=1
		while(m < n)
	endif
end

Proc Correct_LEED_image()
	PROI_correct_LEED_image()
End

Function PROI_correct_LEED_image()
       // data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String waveStr=SIS_getImageStackName()
	prompt waveStr, "choose image"
	variable cali=0.0031 
	Prompt cali, "reciprocal space calibration (inverse angstrom per pixel / 2 Pi)"
	variable units=2
	Prompt units, "units", popup "pixels;inverse angstroms;"
	variable usecrsr=1
	Prompt usecrsr, "zero zero position", popup "cursor A; intensity maximum;"
	variable axis=2
	Prompt axis, "axis", popup "bottom; both;"
	doPrompt "profile rescale input" waveStr, cali, units, usecrsr, axis
	if (V_flag == 0)
		variable np=dimSize($waveStr,0)+1
		variable nq=dimSize($waveStr,1)+1
		String pStr=waveStr+"_P"
		String qStr=waveStr+"_Q"
		Make/n=(np)/o $pStr
		Make/n=(nq)/o $qStr
		wave wp=$pStr
		wave wq=$qStr
		variable zp=NaN
		variable zq=NaN
		cali=cali*2*Pi
		make/n=4/o wcorr={-0.36311,1.0001,2.5782e-005,-3.059e-006}
		if (usecrsr==1)
			zp=pcsr(A)
		 	zq=qcsr(A)
		else
			imagestats/Q $waveStr
			zp=V_maxRowLoc
			zq=V_maxColLoc
		endif
		wp=(p-zp)
		wp=wcorr[0]+wcorr[1]*wp+wcorr[2]*wp^2+wcorr[3]*wp^3
		wq=(p-zq)
		wq=wcorr[0]+wcorr[1]*wq+wcorr[2]*wq^2+wcorr[3]*wq^3	
		//display
		String graphNameStr="CL"+waveStr
		SIS_xyImageToFront(graphNameStr,waveStr,pStr,qStr) 
		if (axis==1) 
			if (units == 1)
				Label bottom "\\F'Arial'\\Z18k\\B\\F'Symbol'//\\M\\F'Arial'\\Z18(Pixels)"	
			else
				wp*=cali
				Label bottom "\\F'Arial'\\Z18k\\B\\F'Symbol'//\\M\\F'Arial'\\Z18(\\S-1\\M\\F'Arial'\\Z18)"
			endif
		else
			if (units == 1)
				Label bottom "\\F'Arial'\\Z18k\\B\\F'Symbol'//\\M\\F'Arial'\\Z18(Pixels)"
				Label left "\\F'Arial'\\Z18k\\B\\F'Symbol'//\\M\\F'Arial'\\Z18(Pixels)"
			else
				wp*=cali
				wq*=cali
				Label bottom "\\F'Arial'\\Z18k\\B\\F'Symbol'//\\M\\F'Arial'\\Z18(\\S-1\\M\\F'Arial'\\Z18)"
				Label left "\\F'Arial'\\Z18k\\B\\F'Symbol'//\\M\\F'Arial'\\Z18(\\S-1\\M\\F'Arial'\\Z18)"
			endif
		endif
		SetAxis/A/R left
		ModifyGraph fSize=12
		ModifyGraph width={Aspect,1}
		ModifyImage $waveStr ctab= {*,250,BrownViolet,1}
	endif
end

Function PROI_killwaves(ctrlname): buttoncontrol
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String stackStr=SIS_getImageStackName()	
	// are you sure?
	variable reply=1
	Prompt reply, "are you sure", popup "yes; no;"
	doPrompt "kill waves" reply
	if (V_flag==0 && reply==1)
		String wavelistStr = WaveList("*", ";","WIN:") 
		variable n=ItemsInList(wavelistStr) 
		variable m=0
		String wavenameStr = ""
		DoWindow/k $winStr
		do
			wavenameStr=StringFromList(m, wavelistStr) 
			wave w = $wavenameStr
			killwaves w
			m+=1
		while(m < n)
	endif
end
	
Function PROI_leftToCoverage(ctrlname): buttoncontrol
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String qStr=winStr+"_Q"
	wave qw=$qStr
	variable czero=min(qw[qcsr(A)],qw[qcsr(B)])
	prompt czero, "coverage zero"
	variable cone=max(qw[qcsr(A)],qw[qcsr(B)])
	prompt cone, "coverage zero"
	DoPrompt "coverage input", czero,cone
	if (V_flag==0)
		qw=(qw[p]-czero)/(cone-czero)
		Label left "\\F'Arial'\\Z18Coverage (ML)"
	endif
end

Function PROI_rightToCoverage(ctrlname): buttoncontrol
	String ctrlname
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String winStr=SIS_getWinName()
	String qStr=winStr+"_C"
	wave qw=$qStr
	variable czero=min(qw[qcsr(A)],qw[qcsr(B)])
	prompt czero, "coverage zero"
	variable cone=max(qw[qcsr(A)],qw[qcsr(B)])
	prompt cone, "coverage zero"
	DoPrompt "coverage input", czero,cone
	if (V_flag==0)
		qw=(qw[p]-czero)/(cone-czero)
		Label right "\\F'Arial'\\Z18Coverage (ML)"
	endif
end

Function PROI_bottomToCoverage(ctrlname): buttoncontrol
	String ctrlname
	String winStr=SIS_getWinName()
	ShowInfo
	SIS_PauseForCursors(winStr,"cursors at 0 and 1")
	// data folder and stack
	String dfStr=SIS_getDataFolderName()
	SetDataFolder root:$(dfStr)
	String pStr=winStr+"_P"
	wave pw=$pStr
	variable czero=min(pw[pcsr(A)],pw[pcsr(B)])
	prompt czero, "coverage zero"
	variable cone=max(pw[pcsr(A)],pw[pcsr(B)])
	prompt cone, "coverage zero"
	DoPrompt "coverage input", czero,cone
	if (V_flag==0)
		pw=(pw[p]-czero)/(cone-czero)
		Label bottom "\\F'Arial'\\Z18Coverage (ML)"
	endif
end

Function/S PROI_giveRoiName(defaultName)
	String defaultName
	Prompt defaultName, "Please give ROI scan a name: "		
	DoPrompt "ROI Scan name", defaultName
	if (V_flag==0)
		return defaultName
	else
		return ""
	endif
End

Function/S PROI_removeQuotes(str)
	String str 
	variable n=strlen(str)
	if (stringMatch(str[n-1],"'")==1)
		str=str[0,n-2]
	endif
	// get rid of first ' 
	n=strlen(str)
	if (stringMatch(str[0],"'")==1)
		str=str[1, n-1]
	endif
	return str
end

Function/S PROI_returnListFirstElement(str,separator)
	String str
	String separator
	variable n=strlen(str)
	variable j=0
	do
		j+=1;			
	while(j<n && stringMatch(str[j],separator)==0)
	str=str[0,j-1]
	return str
end

